@@ -63,7 +63,8 @@ OC.L10N.register(
     "{actor} deleted a message" : "הודעה נמחקה על ידי {actor}",
     "You deleted a message" : "מחקת הודעה",
     "Message deleted by author" : "ההודעה נמחקה על ידי מי שפרסם אותה",
-    "You missed a call from {user}" : "החמצת שיחה עם {user}",
+    "Administration" : "ניהול",
+    "System" : "מערכת",
     "Talk conversations" : "דיוני שיח",
     "File is too big" : "הקובץ גדול מדי",
     "Invalid file provided" : "הקובץ שסופק שגוי",
@@ -73,7 +74,7 @@ OC.L10N.register(
     "No unread mentions" : "אין אזכורים שלא נקראו",
     "Call in progress" : "מתנהלת שיחה",
     "Conversation invitation" : "הזמנה לדיון",
-    "Click the button below to join." : "יש ללחוץ על הכפתור שלהלן כדי להצטרף.",
+    "Description" : "תיאור",
     "Meeting ID" : "מזהה פגישה",
     "Password request: %s" : "בקשת ססמה: %s",
     "Private conversation" : "דיון פרטי",
@@ -82,11 +83,11 @@ OC.L10N.register(
     "Accept" : "אשר",
     "Decline" : "דחייה",
     "{user} sent you a private message" : "התקבלה הודעה פרטית מאת {user}",
-    "{user} invited you to a private conversation" : "הוזמנת לדיון פרטי על ידי {user}",
-    "Join call" : "הצטרפות לשיחה",
     "{user} invited you to a group conversation: {call}" : "הוזמנת על ידי {user} לדיון קבוצתי: {call}",
+    "Join call" : "הצטרפות לשיחה",
     "Answer call" : "לענות לשיחה",
     "Call back" : "להתקשר בחזרה",
+    "You missed a call from {user}" : "החמצת שיחה עם {user}",
     "A group call has started in {call}" : "החלה שיחה קבוצתית תחת {call}",
     "Open settings" : "פתיחת הגדרות",
     "error" : "שגיאה",
@@ -336,12 +337,12 @@ OC.L10N.register(
     "South Africa" : "דרום אפריקה",
     "Zambia" : "זמביה",
     "Zimbabwe" : "זימבבואה",
+    "Federation" : "איגוד",
     "Invalid date, date format must be YYYY-MM-DD" : "תאריך לא חוקי, תבנית התאריך חייבת להיות YYYY-MM-DD",
     "Conversation not found" : "הדיון לא נמצא",
-    "Navigating away from the page will leave the call in {conversation}" : "ניווט מחוץ לעמוד תנתק את השיחה שב־{conversation}",
     "Leave call" : "יציאה מהשיחה",
+    "Navigating away from the page will leave the call in {conversation}" : "ניווט מחוץ לעמוד תנתק את השיחה שב־{conversation}",
     "Stay in call" : "להישאר בשיחה",
-    "Duplicate session" : "שכפול הפעלה",
     "Discuss this file" : "לדון על הקובץ הזה",
     "Share this file with others to discuss it" : "שיתוף הקובץ הזה לדיונם של אחרים",
     "Share this file" : "שיתוף הקובץ הזה",
@@ -349,61 +350,70 @@ OC.L10N.register(
     "Request password" : "בקשת ססמה",
     "Error requesting the password." : "בקשת הססמה נכשלה.",
     "This conversation has ended" : "הדיון הסתיים",
-    "Limit to groups" : "הגבלה לקבוצות",
-    "Limit starting a call" : "הגבלת התחלת שיחה",
-    "Limit starting calls" : "הגבלת התחלת שיחות",
     "Everyone" : "כולם",
     "Users and moderators" : "משתמשים ומפקחים",
     "Moderators only" : "מפקחים בלבד",
     "Save changes" : "שמירת שינויים",
     "Saving …" : "מתבצעת שמירה…",
     "Saved!" : "נשמר!",
-    "State" : "מצב",
-    "Name" : "שם",
-    "Description" : "תיאור",
+    "Limit to groups" : "הגבלה לקבוצות",
+    "Limit starting a call" : "הגבלת התחלת שיחה",
+    "Limit starting calls" : "הגבלת התחלת שיחות",
     "Enabled" : "מופעל",
     "Disabled" : "מושבת",
-    "Federation" : "איגוד",
+    "State" : "מצב",
+    "Name" : "שם",
     "Beta" : "בטא",
     "Permissions" : "הרשאות",
-    "General settings" : "הגדרות כלליות",
     "All messages" : "כל ההודעות",
     "Off" : "כבוי",
-    "Language" : "שפה",
-    "Country" : "מדינה",
-    "Status" : "מצב",
-    "Created at" : "נוצר ב־",
+    "General settings" : "הגדרות כלליות",
+    "Enable encryption" : "אפשר הצפנה",
     "Pending" : "בהמתנה",
     "Error" : "שגיאה",
     "Blocked" : "נחסם",
     "Active" : "פעיל",
     "Expired" : "פג",
-    "Matterbridge integration" : "שילוב עם Matterbridge",
-    "Enable Matterbridge integration" : "הפעלת שילוב עם Matterbridge",
+    "Language" : "שפה",
+    "Country" : "מדינה",
+    "Status" : "מצב",
+    "Created at" : "נוצר ב־",
     "Installed version: {version}" : "גרסה מותקנת: {version}",
     "Downloading …" : "מתבצעת הורדה…",
     "Failed to execute Matterbridge binary." : "הפעלת הבינרי של Matterbridge נכשלה.",
+    "Matterbridge integration" : "שילוב עם Matterbridge",
+    "Enable Matterbridge integration" : "הפעלת שילוב עם Matterbridge",
     "Validate SSL certificate" : "אימות אישור SSL",
     "Delete this server" : "מחיקת השרת הזה",
+    "Test this server" : "בדיקת השרת הזה",
     "Shared secret" : "סוד משותף",
     "STUN server URL" : "כתובת שרת STUN",
     "STUN servers" : "שרתי STUN",
     "A STUN server is used to determine the public IP address of participants behind a router." : "שרת STUN משמש לאיתור כתובת ה־IP הציבורית של המשתמשים מאחורי נתב.",
     "TURN server URL" : "כתובת שרת TURN",
     "TURN server protocols" : "פרוטוקולים לשרתים מסוג TURN",
-    "Test this server" : "בדיקת השרת הזה",
     "TURN servers" : "שרתי TURN",
     "OK" : "אישור",
     "Checking …" : "מתבצעת בדיקה…",
-    "Back" : "חזרה",
-    "Cancel" : "ביטול",
     "Confirm" : "אימות",
     "Reset" : "איפוס",
-    "Copy link" : "העתקת קישור",
+    "Back" : "חזרה",
+    "Cancel" : "ביטול",
+    "Loading …" : "בטעינה…",
+    "No upcoming events" : "אין אירועים בזמן הקרוב",
+    "From" : "מאת",
+    "To" : "אל",
+    "Calendar" : "לוח שנה",
+    "Attendees" : "משתתפים",
+    "Save" : "שמירה",
+    "Search participants" : "חיפוש משתתפים",
+    "No results" : "אין תוצאות",
+    "Done" : "הסתיים",
     "Waiting for others to join the call …" : "בהמתנה לאחרים להצטרף לשיחה…",
     "You can invite others in the participant tab of the sidebar" : "ניתן להזמין אחרים בלשונית המשתתפים בסרגל הצד",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "ניתן להזמין אחרים דרך לשונית המשתפים בסרגל הצד או לשתף את הקישור הזה כדי להזמין אחרים!",
     "Share this link to invite others!" : "יש לשתף את הקישור הזה כדי להזמין אחרים!",
+    "Copy link" : "העתקת קישור",
     "Mute audio" : "השתקת שמע",
     "Disable video" : "השבתת וידאו",
     "Enable video" : "הפעלת וידאו",
@@ -412,11 +422,10 @@ OC.L10N.register(
     "Collapse" : "קיווץ",
     "Drop your files to upload" : "יש לגרור לכאן קבצים כדי להעלות",
     "Favorite" : "סימון כמועדף",
-    "Loading …" : "בטעינה…",
-    "Hide details" : "הסתרת פרטים",
-    "Show details" : "הצגת פרטים",
     "Date:" : "בתאריך:",
     "Note:" : "הערה:",
+    "Hide details" : "הסתרת פרטים",
+    "Show details" : "הצגת פרטים",
     "Disable" : "השבתה",
     "Choose" : "בחר",
     "Restricted" : "מוגבלת",
@@ -428,13 +437,116 @@ OC.L10N.register(
     "_%n hour_::_%n hours_" : ["שעה","שעתיים","%n שעות"],
     "_%n day_::_%n days_" : ["יום","יומיים","%n ימים"],
     "Password protection" : "הגנה בססמה",
-    "Copy conversation link" : "העתקת קישור דיון",
+    "Set a password" : "הגדרת ססמה",
     "Start time (optional)" : "מועד התחלה (רשות)",
-    "Save" : "שמירה",
     "Edit" : "עריכה",
     "More information" : "מידע נוסף",
     "Delete" : "מחיקה",
+    "unknown state" : "מצב לא ידוע",
+    "Bridge saved" : "הגישור נשמר",
     "Log content" : "תוכן הרישום",
+    "Notifications" : "התראות",
+    "Error while creating the conversation" : "שגיאה ביצירת הדיון",
+    "Create conversation" : "יצירת דיון",
+    "Enter your name" : "נא למלא את שמך",
+    "Log in" : "כניסה",
+    "Mark as read" : "סימון כנקרא",
+    "Mark as unread" : "סימון כלא נקרא",
+    "Remove from favorites" : "הסרה מהמועדפים",
+    "Add to favorites" : "הוספה למועדפים",
+    "No matches found" : "לא נמצאו התאמות",
+    "An error occurred while performing the search" : "אירעה שגיאה בעת ביצוע החיפוש",
+    "Clear filter" : "מחיקת מסנן",
+    "Users" : "משתמשים",
+    "Groups" : "קבוצות",
+    "Other sources" : "מקורות אחרים",
+    "You are currently waiting in the lobby" : "הנך בהמתנה בלובי",
+    "None" : "אין",
+    "Devices" : "מכשירים",
+    "No audio" : "אין שמע",
+    "Invalid path selected" : "הנתיב שנבחר שגוי",
+    "Upload" : "העלאה",
+    "Files" : "קבצים",
+    "Message sent" : "הודעה נשלחה",
+    "Deleting message" : "ההודעה נמחקה",
+    "Unread messages" : "הודעות שלא נקראו",
+    "Reply" : "תגובה",
+    "Go to file" : "מעבר לקובץ",
+    "Translate" : "תרגום",
+    "Dismiss" : "התעלמות",
+    "Contact" : "איש/אשת קשר",
+    "Today" : "היום",
+    "Yesterday" : "מחר",
+    "_%n day ago_::_%n days ago_" : ["לפני %n יום","לפני %n ימים","לפני %n ימים","לפני %n ימים"],
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
+    "No messages" : "אין הודעות",
+    "Create a new group conversation" : "יצירת דיון קבוצתי חדש",
+    "Add participants" : "הוספת משתתפים",
+    "Send message" : "שליחת הודעה",
+    "Add emoji" : "הוספת אמוג׳י",
+    "File to share" : "קובץ לשיתוף",
+    "Share from Files" : "שיתוף מקבצים",
+    "Share files to the conversation" : "שיתוף קבצים לדיון",
+    "Create new poll" : "יצירת סקר חדש",
+    "New file" : "קובץ חדש",
+    "Add more files" : "הוספת קבצים נוספים",
+    "Send" : "שליחה",
+    "Create poll" : "יצירת סקר",
+    "Settings" : "הגדרות",
+    "Anonymous poll" : "סקר אלמוני",
+    "Join" : "הצטרף",
+    "moderator" : "מפקח/ת",
+    "guest" : "אורח",
+    "Remove group and members" : "הסרת קבוצה וחברים",
+    "Remove participant" : "הסרת משתתף",
+    "Demote from moderator" : "הורדה מדרגת פיקוח",
+    "Promote to moderator" : "קידום לדרגת פיקוח",
+    "Remove" : "הסרה",
+    "Add users or groups" : "הוספת משתמשים או קבוצות",
+    "Add groups" : "הוספת קבוצות",
+    "Add other sources" : "הוספת מקורות אחרים",
+    "Add emails" : "הוספת כתובות דוא״ל",
+    "Integrations" : "שילובים",
+    "Searching …" : "מתבצע חיפוש…",
+    "Participants" : "משתתפים",
+    "Chat" : "צ׳אט",
+    "Details" : "פרטים",
+    "Load more results" : "לטעון עוד תוצאות",
+    "Projects" : "מיזמים",
+    "Link to a conversation" : "קישור לדיון",
+    "Select conversation" : "בחירת דיון",
+    "Calls are not supported in your browser" : "אין תמיכה בשיחות בדפדפן שלך",
+    "Access to microphone was denied" : "הגישה למיקרופון נדחתה",
+    "Choose devices" : "בחירת התקנים",
+    "Attachments folder" : "תיקיית הקבצים המצורפים",
+    "Select location for attachments" : "בחירת מיקום לקבצים מצורפים",
+    "Appearance" : "מראה",
+    "Privacy" : "פרטיות",
+    "Performance" : "ביצועים",
+    "Keyboard shortcuts" : "קיצורי מקלדת",
+    "Search" : "חיפוש",
+    "Shortcuts while in a call" : "קיצורי דרך בזמן שיחה",
+    "Start call" : "התחלת שיחה",
+    "Screensharing options" : "אפשרויות שיתוף מסך",
+    "Enable screensharing" : "הפעלת שיתוף מסך",
+    "Screensharing requires the page to be loaded through HTTPS." : "לטובת שיתוף מסך יש לטעון את העמוד דרך HTTPS.",
+    "Sharing your screen only works with Firefox version 52 or newer." : "שיתוף מסך עובד עם Firefox בגרסה 52 ומעלה.",
+    "Screensharing extension is required to share your screen." : "נדרשת הרחבה לשיתוף המסך כדי לשתף את המסך.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "נא להשתמש בדפדפן אחר כגון Firefox או Chrome כדי לשתף את המסך שלך.",
+    "An error occurred while starting screensharing." : "אירעה שגיאה בעת התחלת שיתוף המסך.",
+    "Show your screen" : "הצגת המסך שלך",
+    "Stop screensharing" : "הפסקת שיתוף המסך",
+    "Speaker view" : "תצוגת דובר",
+    "Grid view" : "תצוגת טבלה",
+    "Mute others" : "השתקה של אחרים",
+    "Select a region" : "נא לבחור איזור",
+    "Submit" : "שליחה",
+    "Message without mention" : "הודעה ללא אזכור",
+    "Mention myself" : "אזכור עצמי",
+    "The conversation does not exist" : "הדיון לא קיים",
+    "Join a conversation or start a new one!" : "הצטרפות לדיון או ליצור אחד חדש!",
+    "Duplicate session" : "שכפול הפעלה",
+    "Join a conversation or start a new one" : "ניתן להצטרף לדיון או להתחיל באחד חדש.",
     "Nextcloud URL" : "כתובת Nextcloud",
     "Nextcloud user" : "משתמש Nextcloud",
     "User password" : "ססמת משתמש",
@@ -455,7 +567,6 @@ OC.L10N.register(
     "API token" : "אסימון API",
     "Slack channel" : "ערוץ Slack",
     "Server ID or name" : "מזהה או שם שרת",
-    "Channel ID or name" : "מזהה ערוץ או שם",
     "Channel" : "ערוץ",
     "Login" : "התחבר",
     "Chat ID" : "מזהה צ׳אט",
@@ -467,117 +578,15 @@ OC.L10N.register(
     "Thread ID" : "מזהה שרשור",
     "MUC server URL" : "כתובת שרת MUC",
     "Jabber ID" : "מזהה Jabber",
-    "unknown state" : "מצב לא ידוע",
-    "Bridge saved" : "הגישור נשמר",
-    "Notifications" : "התראות",
-    "Enter your name" : "נא למלא את שמך",
-    "Mark as read" : "סימון כנקרא",
-    "Mark as unread" : "סימון כלא נקרא",
-    "Remove from favorites" : "הסרה מהמועדפים",
-    "Add to favorites" : "הוספה למועדפים",
-    "Clear filter" : "מחיקת מסנן",
-    "No matches found" : "לא נמצאו התאמות",
-    "Users" : "משתמשים",
-    "Groups" : "קבוצות",
-    "Loading" : "בטעינה",
-    "Other sources" : "מקורות אחרים",
-    "An error occurred while performing the search" : "אירעה שגיאה בעת ביצוע החיפוש",
-    "You are currently waiting in the lobby" : "הנך בהמתנה בלובי",
-    "None" : "אין",
-    "Devices" : "מכשירים",
-    "No audio" : "אין שמע",
-    "Upload" : "העלאה",
-    "Files" : "קבצים",
-    "File to share" : "קובץ לשיתוף",
-    "Invalid path selected" : "הנתיב שנבחר שגוי",
-    "Unread messages" : "הודעות שלא נקראו",
-    "Message sent" : "הודעה נשלחה",
-    "Deleting message" : "ההודעה נמחקה",
-    "Reply" : "תגובה",
-    "Go to file" : "מעבר לקובץ",
-    "Translate" : "תרגום",
-    "Dismiss" : "התעלמות",
-    "Contact" : "איש/אשת קשר",
-    "No messages" : "אין הודעות",
-    "Today" : "היום",
-    "Yesterday" : "מחר",
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
-    "_%n day ago_::_%n days ago_" : ["לפני %n יום","לפני %n ימים","לפני %n ימים","לפני %n ימים"],
-    "Search participants" : "חיפוש משתתפים",
-    "Create a new group conversation" : "יצירת דיון קבוצתי חדש",
-    "Create conversation" : "יצירת דיון",
-    "Add participants" : "הוספת משתתפים",
-    "Close" : "סגירה",
-    "Error while creating the conversation" : "שגיאה ביצירת הדיון",
-    "Password protect" : "הגנה בססמה",
-    "Add emoji" : "הוספת אמוג׳י",
-    "Send message" : "שליחת הודעה",
-    "Group" : "קבוצה",
-    "Share files to the conversation" : "שיתוף קבצים לדיון",
-    "Create new poll" : "יצירת סקר חדש",
-    "New file" : "קובץ חדש",
-    "Settings" : "הגדרות",
-    "Create poll" : "יצירת סקר",
-    "Send" : "שליחה",
-    "Add more files" : "הוספת קבצים נוספים",
-    "Join" : "הצטרף",
-    "moderator" : "מפקח/ת",
-    "guest" : "אורח",
-    "Demote from moderator" : "הורדה מדרגת פיקוח",
-    "Promote to moderator" : "קידום לדרגת פיקוח",
-    "Remove" : "הסרה",
-    "Remove group and members" : "הסרת קבוצה וחברים",
-    "Remove participant" : "הסרת משתתף",
-    "Add groups" : "הוספת קבוצות",
-    "Add emails" : "הוספת כתובות דוא״ל",
-    "Integrations" : "שילובים",
-    "Searching …" : "מתבצע חיפוש…",
-    "No results" : "אין תוצאות",
-    "Add users or groups" : "הוספת משתמשים או קבוצות",
-    "Add other sources" : "הוספת מקורות אחרים",
-    "Participants" : "משתתפים",
-    "Chat" : "צ׳אט",
-    "Details" : "פרטים",
-    "Projects" : "מיזמים",
-    "Select conversation" : "בחירת דיון",
-    "Link to a conversation" : "קישור לדיון",
-    "Calls are not supported in your browser" : "אין תמיכה בשיחות בדפדפן שלך",
-    "Access to microphone was denied" : "הגישה למיקרופון נדחתה",
-    "Choose devices" : "בחירת התקנים",
-    "Attachments folder" : "תיקיית הקבצים המצורפים",
-    "Select location for attachments" : "בחירת מיקום לקבצים מצורפים",
-    "Privacy" : "פרטיות",
-    "Performance" : "ביצועים",
-    "Keyboard shortcuts" : "קיצורי מקלדת",
-    "Search" : "חיפוש",
-    "Shortcuts while in a call" : "קיצורי דרך בזמן שיחה",
-    "Start call" : "התחלת שיחה",
-    "Show your screen" : "הצגת המסך שלך",
-    "Stop screensharing" : "הפסקת שיתוף המסך",
-    "Screensharing options" : "אפשרויות שיתוף מסך",
-    "Enable screensharing" : "הפעלת שיתוף מסך",
-    "Screensharing requires the page to be loaded through HTTPS." : "לטובת שיתוף מסך יש לטעון את העמוד דרך HTTPS.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "שיתוף מסך עובד עם Firefox בגרסה 52 ומעלה.",
-    "Screensharing extension is required to share your screen." : "נדרשת הרחבה לשיתוף המסך כדי לשתף את המסך.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "נא להשתמש בדפדפן אחר כגון Firefox או Chrome כדי לשתף את המסך שלך.",
-    "An error occurred while starting screensharing." : "אירעה שגיאה בעת התחלת שיתוף המסך.",
-    "Mute others" : "השתקה של אחרים",
-    "Speaker view" : "תצוגת דובר",
-    "Grid view" : "תצוגת טבלה",
-    "Select a region" : "נא לבחור איזור",
-    "Submit" : "שליחה",
-    "Message without mention" : "הודעה ללא אזכור",
-    "Mention myself" : "אזכור עצמי",
-    "The conversation does not exist" : "הדיון לא קיים",
-    "Join a conversation or start a new one!" : "הצטרפות לדיון או ליצור אחד חדש!",
-    "Join a conversation or start a new one" : "ניתן להצטרף לדיון או להתחיל באחד חדש.",
     "Media" : "מדיה",
     "Polls" : "סקרים",
     "Locations" : "מיקומים",
     "Audio" : "שמע",
     "Other" : "אחר",
+    "Group" : "קבוצה",
     "Error while sharing file" : "שגיאה בשיתוף הקובץ",
     "An error occurred while fetching the participants" : "אירעה שגיאה במהלך קבלת המשתתפים",
+    "Please reload the page." : "יש להעלות מחדש דף זה.",
     "Do not disturb" : "לא להפריע",
     "Away" : "לא פה",
     "Default" : "בררת מחדל",
@@ -591,23 +600,12 @@ OC.L10N.register(
     "The password is wrong. Try again." : "הססמה שגויה. נא לנסות שוב.",
     "Android app" : "יישומון ל־Android",
     "iOS app" : "יישומון ל־iOS",
-    "There are currently no commands available." : "אין פקודות זמינות.",
-    "The command does not exist" : "הפקודה לא קיימת",
-    "An error occurred while running the command. Please ask an administrator to check the logs." : "אירעה שגיאה בעת הפעלת הפקודה. נא לבקש מהנהלת המערכת לבדוק את יומן התיעוד.",
-    "Commands" : "פקודות",
-    "Command" : "פקודה",
-    "Script" : "סקריפט",
-    "Response to" : "תגובה אל",
-    "Enabled for" : "מופעל עבור",
-    "Moderators" : "מפקחים",
-    "Circles" : "מעגלים",
-    "Groups and circles" : "קבוצות ומעגלים",
-    "Add circles" : "הוספת מעגלים",
-    "Add groups or circles" : "הוספת קבוצות או מעגלים",
-    "Open sidebar" : "פתיחת סרגל הצד",
-    "Start a conversation" : "התחלת דיון",
-    "TURN server" : "שרת TURN",
-    "The TURN server is used to proxy the traffic from participants behind a firewall." : "שרת ה־TURN משמש לתיווך התעבורה מהמשתמשים שנמצאים מאחורי חומת אש.",
-    "Signaling servers" : "שרתי איתות"
+    "__language_name__" : "עברית",
+    "Tasks" : "משימות",
+    "Notes" : "פתקים",
+    "Click the button below to join." : "יש ללחוץ על הכפתור שלהלן כדי להצטרף.",
+    "{user} invited you to a private conversation" : "הוזמנת לדיון פרטי על ידי {user}",
+    "Copy conversation link" : "העתקת קישור דיון",
+    "Close" : "סגירה"
 },
 "nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
