@@ -3,11 +3,14 @@ OC.L10N.register(
     {
     "Talk" : "Prat",
     "Guest" : "Gjest",
+    "Administration" : "Administrasjon",
+    "System" : "System",
     "File is too big" : "Fila er for stor",
     "Invalid file provided" : "Ugyldig fil",
     "Invalid image" : "Ugyldig bilete",
     "Unknown filetype" : "Ukjend filtype",
     "Say hi to your friends and colleagues!" : "Sei hei til dine venner og kollegar!",
+    "Description" : "Skildring",
     "Open settings" : "Opne instillingar",
     "Messages" : "Meldingar",
     "Albania" : "Albania",
@@ -46,18 +49,21 @@ OC.L10N.register(
     "Netherlands" : "Nederland",
     "Norway" : "Noreg",
     "Everyone" : "Alle",
-    "Name" : "Namn",
-    "Description" : "Skildring",
     "Disabled" : "Deaktivert",
+    "Name" : "Namn",
+    "Enable encryption" : "Aktiver kryptering",
+    "Pending" : "Under vegs",
+    "Error" : "Feil",
     "Language" : "Språk",
     "Country" : "Land",
     "Status" : "Status",
     "Created at" : "Skapt den",
-    "Pending" : "Under vegs",
-    "Error" : "Feil",
     "OK" : "OK",
     "Back" : "Tilbake",
     "Cancel" : "Avbryt",
+    "Calendar" : "Kalendar",
+    "Attendees" : "Deltakarar",
+    "Save" : "Lagre",
     "Copy link" : "Kopier lenkje",
     "Favorite" : "Favoritt",
     "Disable" : "Slå av",
@@ -67,22 +73,21 @@ OC.L10N.register(
     "Leave conversation" : "Forlat samtalen",
     "Delete conversation" : "Slett samtale",
     "Password protection" : "Password protection",
-    "Save" : "Lagre",
+    "Set a password" : "Lag eit passord",
     "Edit" : "Endra",
     "More information" : "Meir informasjon",
     "Delete" : "Slett",
     "Notifications" : "Varsel",
-    "Login" : "Login",
+    "Log in" : "Logg inn",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
     "Users" : "Brukarare",
     "Groups" : "Grupper",
-    "Loading" : "Loading",
     "None" : "Ingen",
     "Upload" : "Last opp",
     "Files" : "Filer",
-    "Unread messages" : "Meldingar er ikkje lest",
     "Message sent" : "Melding sendt",
+    "Unread messages" : "Meldingar er ikkje lest",
     "Reply" : "Svare",
     "Reply privately" : "Svar privat",
     "Dismiss" : "Forkast",
@@ -91,21 +96,20 @@ OC.L10N.register(
     "Yesterday" : "i går",
     "_%n day ago_::_%n days ago_" : ["%n dag sidan","%n dagar sidan"],
     "Add participants" : "Legg til deltakarar",
-    "Close" : "Lukk",
-    "Password protect" : "Vern med passord",
     "Send message" : "Send melding",
     "Record voice message" : "Ta opp lyd melding ",
-    "Settings" : "Instillingar",
     "Send" : "Send",
-    "Demote from moderator" : "Nedrykk frå moderator",
-    "Promote to moderator" : "Fremje til moderator",
+    "Settings" : "Instillingar",
     "Remove group and members" : "Eksterne gruppe og medlemmar",
     "Remove participant" : "Eksterne deltakarar",
+    "Demote from moderator" : "Nedrykk frå moderator",
+    "Promote to moderator" : "Fremje til moderator",
     "Add users or groups" : "Add users or groups",
     "Participants" : "Deltakarar",
+    "Open chat" : "Start lynmelding",
     "Chat" : "Lynmelding",
     "Details" : "Detaljar",
-    "Open chat" : "Start lynmelding",
+    "Appearance" : "Utsjånad",
     "Privacy" : "Personvern",
     "Keyboard shortcuts" : "Tastatursnarvegar",
     "Search" : "Search",
@@ -113,14 +117,17 @@ OC.L10N.register(
     "Join a conversation or start a new one" : "Delta i ein samtale eller start ein ny ein",
     "User" : "Bruker",
     "Password" : "Passord",
+    "Login" : "Login",
     "Nickname" : "Kallenamn",
     "Client ID" : "Klient-ID",
     "Other" : "Anna",
     "Group" : "Gruppe",
+    "Please reload the page." : "Ver venleg og last sida på nytt.",
     "Away" : "Borte",
     "Default" : "Standard",
     "The password is wrong. Try again." : "Passordet er gale. Prøv igjen.",
-    "Circles" : "Sirklar",
-    "Remove circle and members" : "Eksterne sirklar og medlemmar"
+    "__language_name__" : "Nynorsk",
+    "Tasks" : "Oppgåver",
+    "Close" : "Lukk"
 },
 "nplurals=2; plural=(n != 1);");
