@@ -5,10 +5,12 @@ OC.L10N.register(
     "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} ได้ตั้งค่า Matterbridge เพื่อซิงโครไนซ์การสนทนานี้กับแชทอื่น ๆ",
     "You set up Matterbridge to synchronize this conversation with other chats" : "คุณได้ตั้งค่า Matterbridge เพื่อซิงโครไนซ์การสนทนานี้กับแชทอื่น ๆ",
     "Message deleted by author" : "ข้อความถูกลบโดยผู้เขียน",
+    "System" : "ระบบ",
     "File is too big" : "ไฟล์ใหญ่เกินไป",
     "Invalid file provided" : "ไฟล์ที่ระบุไม่ถูกต้อง",
     "Invalid image" : "รูปภาพไม่ถูกต้อง",
     "Unknown filetype" : "ชนิดไฟล์ที่ไม่รู้จัก",
+    "Description" : "รายละเอียด",
     "Dismiss notification" : "ปิดการแจ้งเตือน",
     "Accept" : "ยอมรับ",
     "Decline" : "ปฏิเสธ",
@@ -20,23 +22,27 @@ OC.L10N.register(
     "Everyone" : "ทุกคน",
     "Save changes" : "บันทึกการเปลี่ยนแปลง",
     "Saving …" : "กำลังบันทึก …",
-    "Name" : "ชื่อ",
-    "Description" : "รายละเอียด",
     "Enabled" : "เปิดใช้งาน",
     "Disabled" : "ปิดใช้งาน",
+    "Name" : "ชื่อ",
     "All messages" : "ข้อความทั้งหมด",
     "@-mentions only" : "เฉพาะการกล่าวถึงแบบ @",
+    "Enable encryption" : "เปิดใช้งานการเข้ารหัส",
+    "Pending" : "รอดำเนินการ",
+    "Error" : "ข้อผิดพลาด",
     "Language" : "ภาษา",
     "Country" : "ประเทศ",
     "Status" : "สถานะ",
     "Created at" : "สร้างเมื่อ",
-    "Pending" : "รอดำเนินการ",
-    "Error" : "ข้อผิดพลาด",
     "OK" : "ตกลง",
-    "Back" : "ย้อนกลับ",
-    "Cancel" : "ยกเลิก",
     "Confirm" : "ยืนยัน",
     "Reset" : "รีเซ็ต",
+    "Back" : "ย้อนกลับ",
+    "Cancel" : "ยกเลิก",
+    "Calendar" : "ปฏิทิน",
+    "Attendees" : "ผู้เข้าร่วมกิจกรรม",
+    "Save" : "บันทึก",
+    "No results" : "ไม่มีผลลัพธ์",
     "Copy link" : "คัดลอกลิงก์",
     "Collapse" : "ย่อ",
     "Favorite" : "รายการโปรด",
@@ -49,21 +55,19 @@ OC.L10N.register(
     "No" : "ไม่ตกลง",
     "Yes" : "ใช่",
     "Password protection" : "ป้องกันด้วยรหัสผ่าน",
-    "Save" : "บันทึก",
     "Edit" : "แก้ไข",
     "Delete" : "ลบ",
     "Notifications" : "การแจ้งเตือน",
-    "Login" : "เข้าสู่ระบบ",
+    "Log in" : "เข้าสู่ระบบ",
     "Remove from favorites" : "เอาออกจากรายการโปรด",
     "Add to favorites" : "เพิ่มในรายการโปรด",
     "Users" : "ผู้ใช้",
     "Groups" : "กลุ่ม",
-    "Loading" : "กำลังโหลด",
     "None" : "ไม่มี",
     "Devices" : "อุปกรณ์",
+    "Invalid path selected" : "เลือกเส้นทางไม่ถูกต้อง",
     "Upload" : "อัปโหลด",
     "Files" : "ไฟล์",
-    "Invalid path selected" : "เลือกเส้นทางไม่ถูกต้อง",
     "Reply" : "ตอบกลับ",
     "Translate" : "แปลภาษา",
     "Dismiss" : "ปิดทิ้ง",
@@ -71,20 +75,19 @@ OC.L10N.register(
     "Yesterday" : "เมื่อวาน",
     "_%n day ago_::_%n days ago_" : ["%n วันที่ผ่านมา"],
     "Add participants" : "เพิ่มผู้เข้าร่วม",
-    "Close" : "ปิด",
-    "Password protect" : "ป้องกันด้วยรหัสผ่าน",
     "New file" : "ไฟล์ใหม่",
     "Blank" : "ว่าง",
-    "Settings" : "การตั้งค่า",
     "Send" : "ส่ง",
+    "Settings" : "การตั้งค่า",
     "bot" : "บอต",
     "guest" : "ผู้เยี่ยมชม",
     "Remove" : "ลบออก",
-    "Searching …" : "กำลังค้นหา …",
-    "No results" : "ไม่มีผลลัพธ์",
     "Add users or groups" : "เพิ่มผู้ใช้หรือกลุ่ม",
+    "Searching …" : "กำลังค้นหา …",
     "Chat" : "แชท",
     "Details" : "รายละเอียด",
+    "Load more results" : "โหลดผลลัพธ์เพิ่มเติม",
+    "Appearance" : "ลักษณะที่ปรากฏ",
     "Privacy" : "ความเป็นส่วนตัว",
     "Keyboard shortcuts" : "แป้นพิมพ์ลัด",
     "Search" : "ค้นหา",
@@ -92,6 +95,7 @@ OC.L10N.register(
     "Submit" : "ส่ง",
     "User" : "ผู้ใช้",
     "Password" : "รหัสผ่าน",
+    "Login" : "เข้าสู่ระบบ",
     "Nickname" : "ชื่อเล่น",
     "Client ID" : "รหัสไคลเอ็นต์",
     "Media" : "สื่อ",
@@ -99,11 +103,16 @@ OC.L10N.register(
     "Audio" : "เสียง",
     "Other" : "อื่น ๆ",
     "Group" : "กลุ่ม",
+    "Please reload the page." : "โปรดโหลดหน้าเว็บใหม่",
     "Do not disturb" : "ห้ามรบกวน",
     "Away" : "ไม่อยู่",
     "Default" : "ค่าเริ่มต้น",
     "The password is wrong. Try again." : "รหัสผ่านไม่ถูกต้อง กรุณาลองอีกครั้ง",
     "Android app" : "แอป Android",
-    "iOS app" : "แอป iOS"
+    "iOS app" : "แอป iOS",
+    "__language_name__" : "ไทย",
+    "Tasks" : "งาน",
+    "Notes" : "โน้ต",
+    "Close" : "ปิด"
 },
 "nplurals=1; plural=0;");
