@@ -2,23 +2,8 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2019 Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Settings\Admin;
@@ -26,10 +11,8 @@ namespace OCA\Talk\Settings\Admin;
 use OCA\Talk\Config;
 use OCA\Talk\Exceptions\WrongPermissionsException;
 use OCA\Talk\MatterbridgeManager;
-use OCA\Talk\Model\Command;
 use OCA\Talk\Participant;
 use OCA\Talk\Room;
-use OCA\Talk\Service\CommandService;
 use OCP\AppFramework\Http\TemplateResponse;
 use OCP\AppFramework\Services\IAppConfig;
 use OCP\AppFramework\Services\IInitialState;
@@ -42,6 +25,7 @@ use OCP\IUser;
 use OCP\IUserSession;
 use OCP\L10N\IFactory;
 use OCP\Settings\ISettings;
+use OCP\Support\Subscription\IRegistry;
 use OCP\Util;
 
 class AdminSettings implements ISettings {
@@ -51,11 +35,11 @@ class AdminSettings implements ISettings {
 		private Config $talkConfig,
 		private IConfig $serverConfig,
 		private IAppConfig $appConfig,
-		private CommandService $commandService,
 		private IInitialState $initialState,
 		private ICacheFactory $memcacheFactory,
 		private IGroupManager $groupManager,
 		private MatterbridgeManager $bridgeManager,
+		private IRegistry $subscription,
 		IUserSession $userSession,
 		private IL10N $l10n,
 		private IFactory $l10nFactory,
@@ -69,7 +53,6 @@ class AdminSettings implements ISettings {
 	public function getForm(): TemplateResponse {
 		$this->initGeneralSettings();
 		$this->initAllowedGroups();
-		$this->initCommands();
 		$this->initFederation();
 		$this->initMatterbridge();
 		$this->initStunServers();
@@ -81,19 +64,20 @@ class AdminSettings implements ISettings {
 
 
 		Util::addScript('spreed', 'talk-admin-settings');
+		Util::addStyle('spreed', 'talk-admin-settings');
 
 		return new TemplateResponse('spreed', 'settings/admin-settings', [], '');
 	}
 
 	protected function initGeneralSettings(): void {
-		$this->initialState->provideInitialState('default_group_notification', (int) $this->serverConfig->getAppValue('spreed', 'default_group_notification', (string) Participant::NOTIFY_MENTION));
-		$this->initialState->provideInitialState('conversations_files', (int) $this->serverConfig->getAppValue('spreed', 'conversations_files', '1'));
-		$this->initialState->provideInitialState('conversations_files_public_shares', (int) $this->serverConfig->getAppValue('spreed', 'conversations_files_public_shares', '1'));
+		$this->initialState->provideInitialState('default_group_notification', (int)$this->serverConfig->getAppValue('spreed', 'default_group_notification', (string)Participant::NOTIFY_MENTION));
+		$this->initialState->provideInitialState('conversations_files', (int)$this->serverConfig->getAppValue('spreed', 'conversations_files', '1'));
+		$this->initialState->provideInitialState('conversations_files_public_shares', (int)$this->serverConfig->getAppValue('spreed', 'conversations_files_public_shares', '1'));
 		$this->initialState->provideInitialState('valid_apache_php_configuration', $this->validApachePHPConfiguration());
 	}
 
 	protected function initAllowedGroups(): void {
-		$this->initialState->provideInitialState('start_calls', (int) $this->serverConfig->getAppValue('spreed', 'start_calls', (string) Room::START_CALL_EVERYONE));
+		$this->initialState->provideInitialState('start_calls', (int)$this->serverConfig->getAppValue('spreed', 'start_calls', (string)Room::START_CALL_EVERYONE));
 
 		$groups = $this->getGroupDetailsArray($this->talkConfig->getAllowedConversationsGroupIds(), 'start_conversations');
 		$this->initialState->provideInitialState('start_conversations', $groups);
@@ -102,16 +86,6 @@ class AdminSettings implements ISettings {
 		$this->initialState->provideInitialState('allowed_groups', $groups);
 	}
 
-	protected function initCommands(): void {
-		$commands = $this->commandService->findAll();
-
-		$result = array_map(function (Command $command) {
-			return $command->asArray();
-		}, $commands);
-
-		$this->initialState->provideInitialState('commands', $result);
-	}
-
 	protected function initFederation(): void {
 		$this->initialState->provideInitialState('federation_enabled', $this->talkConfig->isFederationEnabled());
 		$this->initialState->provideInitialState('federation_incoming_enabled', $this->appConfig->getAppValueBool('federation_incoming_enabled', true));
@@ -123,7 +97,7 @@ class AdminSettings implements ISettings {
 	protected function initMatterbridge(): void {
 		$error = '';
 		try {
-			$version = (string) $this->bridgeManager->getCurrentVersionFromBinary();
+			$version = (string)$this->bridgeManager->getCurrentVersionFromBinary();
 			if ($version === '') {
 				$error = 'binary';
 			}
@@ -154,6 +128,7 @@ class AdminSettings implements ISettings {
 	}
 
 	protected function initSignalingServers(): void {
+		$this->initialState->provideInitialState('has_valid_subscription', $this->subscription->delegateHasValidSubscription());
 		$this->initialState->provideInitialState('has_cache_configured', $this->memcacheFactory->isAvailable());
 		$this->initialState->provideInitialState('signaling_mode', $this->talkConfig->getSignalingMode(false));
 		$this->initialState->provideInitialState('signaling_servers', [
@@ -476,6 +451,8 @@ class AdminSettings implements ISettings {
 			'uploadLimit' => is_infinite($uploadLimit) ? 0 : $uploadLimit,
 		]);
 		$this->initialState->provideInitialState('recording_consent', $this->talkConfig->getRecordingConsentConfig());
+		$this->initialState->provideInitialState('call_recording_transcription', $this->serverConfig->getAppValue('spreed', 'call_recording_transcription', 'no') === 'yes');
+		$this->initialState->provideInitialState('call_recording_summary', $this->serverConfig->getAppValue('spreed', 'call_recording_summary', 'yes') === 'yes');
 	}
 
 	protected function initSIPBridge(): void {
@@ -546,8 +523,8 @@ class AdminSettings implements ISettings {
 
 	/**
 	 * @return int whether the form should be rather on the top or bottom of
-	 * the admin section. The forms are arranged in ascending order of the
-	 * priority values. It is required to return a value between 0 and 100.
+	 *             the admin section. The forms are arranged in ascending order of the
+	 *             priority values. It is required to return a value between 0 and 100.
 	 *
 	 * E.g.: 70
 	 */
